{% extends "layouts/base.html" %} {% block title %}Profile {% endblock %} {% block body_class %} sidebar-mini {% endblock body_class %} {% block stylesheets %} {% endblock stylesheets %} {% block content %}

# Profile

### Nina Mcintire

Software Engineer

- Followers 1,322
- Following 543
- Friends 13,287

Follow

### About Me

Education

B.S. in Computer Science from the University of Tennessee at Knoxville

Location

Malibu, California

Skills

UI Design Coding Javascript PHP Node.js

Notes

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam fermentum enim neque.

Jonathan Burke Jr. Shared publicly - 7:30 PM today

Lorem ipsum represents a long-held tradition for designers, typographers and the like. Some people hate it and argue for its demise, but others ignore the hate as they create awesome tools to help create filler text for everyone from bacon lovers to Charlie Sheen fans.

Share Like Comments (5)

Sarah Ross Sent you a message - 3 days ago

Lorem ipsum represents a long-held tradition for designers, typographers and the like. Some people hate it and argue for its demise, but others ignore the hate as they create awesome tools to help create filler text for everyone from bacon lovers to Charlie Sheen fans.

Adam Jones Posted 5 photos - 5 days ago

Share Like Comments (5)

10 Feb. 2014
12:05

### Support Team sent you an email

Etsy doostang zoodles disqus groupon greplin oooj voxy zoodles, weebly ning heekya handango imeem plugg dopplr jibjab, movity jajah plickers sifteo edmodo ifttt zimbra. Babblely odeo kaboodle quora plaxo ideeli hulu weebly balihoo...
5 mins ago

### Sarah Young accepted your friend request

27 mins ago

### Jay White commented on your post

Take me to your leader! Switzerland is small and neutral! We are more like Germany, ambitious and misunderstood!
3 Jan. 2014
2 days ago

### Mina Lee uploaded new photos

Name
Email
Name
Experience
Skills
I agree to the terms and conditions
{% endblock content %} {% block javascripts %}
{% endblock javascripts %}